@@ -17,17 +17,17 @@
  */
 
 #include "se2_label.h"
+
 #include "se2_error_handling.h"
 #include "se2_neighborlist.h"
+
 #include <igraph.h>
 
 /* Scores labels based on the difference between the local and global
  frequencies.  Labels that are overrepresented locally are likely to be of
  importance in tagging a node. */
-igraph_error_t se2_find_most_specific_labels_i(se2_neighs const *graph,
-    se2_partition *partition,
-    se2_iterator *node_iter,
-    igraph_integer_t *n_moved)
+igraph_error_t se2_find_most_specific_labels_i(se2_neighs const* graph,
+  se2_partition* partition, se2_iterator* node_iter, igraph_integer_t* n_moved)
 {
   se2_iterator label_iter;
   igraph_real_t label_specificity = 0, best_label_specificity = 0;
@@ -41,15 +41,10 @@ igraph_error_t se2_find_most_specific_labels_i(se2_neighs const *graph,
   igraph_integer_t node_id = 0, label_id = 0;
   while ((node_id = se2_iterator_next(node_iter)) != -1) {
     while ((label_id = se2_iterator_next(&label_iter)) != -1) {
-      igraph_real_t actual =
-        MATRIX(*partition->local_labels_heard, node_id, label_id);
-      igraph_real_t expected =
-        VECTOR(*partition->global_labels_heard)[label_id];
-      igraph_real_t norm_factor =
-        VECTOR(*graph->kin)[node_id] / graph->total_weight;
-
-      label_specificity = actual - (norm_factor *expected);
-      if ((best_label == -1) || (label_specificity >= best_label_specificity)) {
+      label_specificity =
+        se2_partition_score_label(graph, partition, node_id, label_id);
+      if ((best_label == -1) ||
+          (label_specificity >= best_label_specificity)) {
         best_label_specificity = label_specificity;
         best_label = label_id;
       }
@@ -59,8 +54,7 @@ igraph_error_t se2_find_most_specific_labels_i(se2_neighs const *graph,
       n_moved_i++;
     }
 
-    se2_partition_add_to_stage(partition, node_id, best_label,
-                               best_label_specificity);
+    se2_partition_add_to_stage(partition, node_id, best_label);
     best_label = -1;
     se2_iterator_shuffle(&label_iter);
   }
@@ -77,16 +71,15 @@ igraph_error_t se2_find_most_specific_labels_i(se2_neighs const *graph,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_find_most_specific_labels(se2_neighs const *graph,
-    se2_partition *partition,
-    igraph_real_t const fraction_nodes_to_label,
-    igraph_bool_t *did_change)
+igraph_error_t se2_find_most_specific_labels(se2_neighs const* graph,
+  se2_partition* partition, igraph_real_t const fraction_nodes_to_label,
+  igraph_bool_t* did_change)
 {
   igraph_integer_t n_moved = 0;
   se2_iterator node_iter;
 
-  SE2_THREAD_CHECK(se2_iterator_random_node_init(&node_iter, partition,
-                   fraction_nodes_to_label));
+  SE2_THREAD_CHECK(se2_iterator_random_node_init(
+    &node_iter, partition, fraction_nodes_to_label));
   IGRAPH_FINALLY(se2_iterator_destroy, &node_iter);
 
   SE2_THREAD_CHECK(
@@ -100,41 +93,69 @@ igraph_error_t se2_find_most_specific_labels(se2_neighs const *graph,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_relabel_worst_nodes(se2_neighs const *graph,
-                                       se2_partition *partition,
-                                       igraph_real_t const fraction_nodes_to_label)
+igraph_error_t se2_relabel_worst_nodes(se2_neighs const* graph,
+  se2_partition* partition, igraph_real_t const fraction_nodes_to_label)
 {
   igraph_integer_t const n_nodes = se2_vcount(graph);
   se2_iterator node_iter;
+  igraph_vector_int_t best_fit_nodes;
+  igraph_vector_int_t best_fit_labels;
+  igraph_integer_t tmp_label = se2_partition_new_label(partition);
 
-  SE2_THREAD_CHECK(se2_iterator_k_worst_fit_nodes_init(
-                     &node_iter, partition, fraction_nodes_to_label *n_nodes));
+  /* The fraction_nodes_to_label variable is used for two different meanings
+   here. Should be broken into two separate arguments. First meaning is the
+   fraction of all nodes in the graph that should be consider poor fitting.
+   Second meaning is the random fraction of poor fitting nodes to relabel. */
+  SE2_THREAD_CHECK(se2_iterator_k_worst_fit_nodes_init(&node_iter, graph,
+    partition, fraction_nodes_to_label * n_nodes, fraction_nodes_to_label,
+    &best_fit_nodes));
   IGRAPH_FINALLY(se2_iterator_destroy, &node_iter);
+  IGRAPH_FINALLY(igraph_vector_int_destroy, &best_fit_nodes);
+
+  SE2_THREAD_CHECK(igraph_vector_int_init(
+    &best_fit_labels, igraph_vector_int_size(&best_fit_nodes)));
+  IGRAPH_FINALLY(igraph_vector_int_destroy, &best_fit_labels);
+  for (igraph_integer_t i = 0; i < igraph_vector_int_size(&best_fit_nodes);
+       i++) {
+    VECTOR(best_fit_labels)[i] = LABEL(*partition)[VECTOR(best_fit_nodes)[i]];
+    se2_partition_add_to_stage(
+      partition, VECTOR(best_fit_nodes)[i], tmp_label);
+  }
+  se2_partition_commit_changes(partition, graph);
 
   SE2_THREAD_CHECK(
     se2_find_most_specific_labels_i(graph, partition, &node_iter, NULL));
+
+  for (igraph_integer_t i = 0; i < igraph_vector_int_size(&best_fit_nodes);
+       i++) {
+    se2_partition_add_to_stage(
+      partition, VECTOR(best_fit_nodes)[i], VECTOR(best_fit_labels)[i]);
+  }
+  se2_partition_commit_changes(partition, graph);
+
+  igraph_vector_int_destroy(&best_fit_labels);
+  igraph_vector_int_destroy(&best_fit_nodes);
   se2_iterator_destroy(&node_iter);
-  IGRAPH_FINALLY_CLEAN(1);
+  IGRAPH_FINALLY_CLEAN(3);
 
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_burst_large_communities(se2_neighs const *graph,
-    se2_partition *partition,
-    igraph_real_t const fraction_nodes_to_move,
-    igraph_integer_t const min_community_size)
+igraph_error_t se2_burst_large_communities(se2_neighs const* graph,
+  se2_partition* partition, igraph_real_t const fraction_nodes_to_move,
+  igraph_integer_t const min_community_size)
 {
   se2_iterator node_iter;
   igraph_vector_int_t n_new_tags_cum;
   igraph_vector_int_t n_nodes_to_move;
   igraph_vector_int_t new_tags;
   igraph_integer_t node_id;
-  igraph_integer_t desired_community_size =
+  igraph_real_t desired_community_size =
     se2_partition_median_community_size(partition);
 
   SE2_THREAD_STATUS();
-  SE2_THREAD_CHECK(se2_iterator_k_worst_fit_nodes_init(
-                     &node_iter, partition, partition->n_nodes *fraction_nodes_to_move));
+  SE2_THREAD_CHECK(se2_iterator_k_worst_fit_nodes_init(&node_iter, graph,
+    partition, partition->n_nodes * fraction_nodes_to_move, 0, NULL));
   IGRAPH_FINALLY(se2_iterator_destroy, &node_iter);
 
   SE2_THREAD_CHECK(
@@ -186,10 +207,10 @@ igraph_error_t se2_burst_large_communities(se2_neighs const *graph,
     current_label = LABEL(*partition)[node_id];
     if (se2_partition_community_size(partition, current_label) >=
         min_community_size) {
-      STAGE(*partition)
-      [node_id] = VECTOR(
-                    new_tags)[RNG_INTEGER(VECTOR(n_new_tags_cum)[current_label],
-                                          VECTOR(n_new_tags_cum)[current_label + 1] - 1)];
+      igraph_integer_t const new_label = VECTOR(
+        new_tags)[RNG_INTEGER(VECTOR(n_new_tags_cum)[current_label],
+        VECTOR(n_new_tags_cum)[current_label + 1] - 1)];
+      se2_partition_add_to_stage(partition, node_id, new_label);
     }
   }
 
@@ -213,11 +234,9 @@ modularity_change: a vector of how much the modularity would change if the
 corresponding merge_candidates were combined.
 
 modularity_change is capped to be always non-negative. */
-static igraph_error_t se2_best_merges(se2_neighs const *graph,
-                                      se2_partition const *partition,
-                                      igraph_vector_int_t *merge_candidates,
-                                      igraph_vector_t *modularity_change,
-                                      igraph_integer_t const n_labels)
+static igraph_error_t se2_best_merges(se2_neighs const* graph,
+  se2_partition const* partition, igraph_vector_int_t* merge_candidates,
+  igraph_vector_t* modularity_change, igraph_integer_t const n_labels)
 {
   igraph_real_t const total_weight =
     HASWEIGHTS(*graph) ? se2_total_weight(graph) : se2_ecount(graph);
@@ -237,7 +256,7 @@ static igraph_error_t se2_best_merges(se2_neighs const *graph,
   for (igraph_integer_t i = 0; i < se2_vcount(graph); i++) {
     for (igraph_integer_t j = 0; j < N_NEIGHBORS(*graph, i); j++) {
       MATRIX(crosstalk, LABEL(*partition)[NEIGHBOR(*graph, i, j)],
-             LABEL(*partition)[i]) += WEIGHT(*graph, i, j);
+        LABEL(*partition)[i]) += WEIGHT(*graph, i, j);
     }
   }
 
@@ -281,8 +300,8 @@ static igraph_error_t se2_best_merges(se2_neighs const *graph,
 /* Since used labels are not necessarily sequential, modularity change can be
 larger than the number of labels in use. To get the median, have to find
 elements of modularity change corresponding to labels in use.*/
-igraph_real_t se2_modularity_median(se2_partition *partition,
-                                    igraph_vector_t *modularity_change)
+igraph_real_t se2_modularity_median(
+  se2_partition* partition, igraph_vector_t* modularity_change)
 {
   igraph_vector_t modularity_change_without_gaps;
   se2_iterator label_iter;
@@ -313,10 +332,9 @@ igraph_real_t se2_modularity_median(se2_partition *partition,
   return res;
 }
 
-igraph_error_t se2_merge_well_connected_communities(se2_neighs const *graph,
-    se2_partition *partition,
-    igraph_real_t *max_prev_merge_threshold,
-    igraph_bool_t *is_partition_stable)
+igraph_error_t se2_merge_well_connected_communities(se2_neighs const* graph,
+  se2_partition* partition, igraph_real_t* max_prev_merge_threshold,
+  igraph_bool_t* is_partition_stable)
 {
   igraph_integer_t max_label = se2_partition_max_label(partition);
   igraph_vector_int_t merge_candidates;
@@ -331,8 +349,8 @@ igraph_error_t se2_merge_well_connected_communities(se2_neighs const *graph,
   SE2_THREAD_CHECK(igraph_vector_init(&modularity_change, max_label + 1));
   IGRAPH_FINALLY(igraph_vector_destroy, &modularity_change);
 
-  SE2_THREAD_CHECK(se2_best_merges(graph, partition, &merge_candidates,
-                                   &modularity_change, max_label + 1));
+  SE2_THREAD_CHECK(se2_best_merges(
+    graph, partition, &merge_candidates, &modularity_change, max_label + 1));
 
   for (igraph_integer_t i = 0; i <= max_label; i++) {
     if (VECTOR(modularity_change)[i] > 0) {
@@ -352,7 +370,7 @@ igraph_error_t se2_merge_well_connected_communities(se2_neighs const *graph,
     VECTOR(modularity_change)
     [i] /=
       (se2_partition_community_size(partition, i) +
-       se2_partition_community_size(partition, VECTOR(merge_candidates)[i]));
+        se2_partition_community_size(partition, VECTOR(merge_candidates)[i]));
   }
 
   min_merge_improvement =
@@ -378,8 +396,8 @@ igraph_error_t se2_merge_well_connected_communities(se2_neighs const *graph,
   SE2_THREAD_CHECK(igraph_vector_int_init(&sort_index, max_label + 1));
   IGRAPH_FINALLY(igraph_vector_int_destroy, &sort_index);
 
-  SE2_THREAD_CHECK(igraph_vector_qsort_ind(&modularity_change, &sort_index,
-                   IGRAPH_DESCENDING));
+  SE2_THREAD_CHECK(igraph_vector_qsort_ind(
+    &modularity_change, &sort_index, IGRAPH_DESCENDING));
 
   if (VECTOR(modularity_change)[VECTOR(sort_index)[0]] <=
       min_merge_improvement) {
