@@ -17,20 +17,19 @@
  */
 
 #include "se2_partitions.h"
+
 #include "se2_error_handling.h"
-#include "se2_interface.h"
 #include "se2_neighborlist.h"
 #include "se2_random.h"
 
 #define MAX(a, b) (a) > (b) ? (a) : (b)
 
-static igraph_integer_t se2_count_labels(igraph_vector_int_t const
-    *membership,
-    igraph_vector_int_t *community_sizes)
+static igraph_integer_t se2_count_labels(
+  igraph_vector_int_t const* membership, igraph_vector_int_t* community_sizes)
 {
-  igraph_integer_t max_label = igraph_vector_int_max(membership);
+  igraph_integer_t const max_label = igraph_vector_int_max(membership);
+  igraph_integer_t const n_nodes = igraph_vector_int_size(membership);
   igraph_integer_t n_labels = 0;
-  igraph_integer_t n_nodes = igraph_vector_int_size(membership);
 
   SE2_THREAD_CHECK_RETURN(
     igraph_vector_int_resize(community_sizes, max_label + 1), 0);
@@ -47,9 +46,9 @@ static igraph_integer_t se2_count_labels(igraph_vector_int_t const
   return n_labels;
 }
 
-static igraph_error_t se2_count_local_labels(
-  se2_neighs const *graph, igraph_vector_int_t const *initial_labels,
-  igraph_integer_t const max_label, igraph_matrix_t *labels_heard)
+static igraph_error_t se2_count_local_labels(se2_neighs const* graph,
+  igraph_vector_int_t const* initial_labels, igraph_integer_t const max_label,
+  igraph_matrix_t* labels_heard)
 {
   igraph_integer_t const n_nodes = igraph_vector_int_size(initial_labels);
   igraph_integer_t const n_labels = max_label + 1;
@@ -70,10 +69,9 @@ static igraph_error_t se2_count_local_labels(
   return IGRAPH_SUCCESS;
 }
 
-static igraph_error_t se2_count_global_labels(se2_neighs const *graph,
-    igraph_integer_t const max_label,
-    igraph_matrix_t const *local_labels_heard,
-    igraph_vector_t *global_labels_heard)
+static igraph_error_t se2_count_global_labels(se2_neighs const* graph,
+  igraph_integer_t const max_label, igraph_matrix_t const* local_labels_heard,
+  igraph_vector_t* global_labels_heard)
 {
   igraph_integer_t const n_labels = max_label + 1;
 
@@ -87,35 +85,30 @@ static igraph_error_t se2_count_global_labels(se2_neighs const *graph,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_partition_init(se2_partition *partition,
-                                  se2_neighs const *graph,
-                                  igraph_vector_int_t const *initial_labels)
+igraph_error_t se2_partition_init(se2_partition* partition,
+  se2_neighs const* graph, igraph_vector_int_t const* initial_labels)
 {
   igraph_integer_t const n_nodes = igraph_vector_int_size(initial_labels);
 
-  igraph_vector_int_t *reference = igraph_malloc(sizeof(*reference));
+  igraph_vector_int_t* reference = igraph_malloc(sizeof(*reference));
   SE2_THREAD_CHECK_OOM(reference);
   IGRAPH_FINALLY(igraph_free, reference);
 
-  igraph_vector_int_t *stage = igraph_malloc(sizeof(*stage));
+  igraph_vector_int_t* stage = igraph_malloc(sizeof(*stage));
   SE2_THREAD_CHECK_OOM(stage);
   IGRAPH_FINALLY(igraph_free, stage);
 
-  igraph_vector_t *specificity = igraph_malloc(sizeof(*specificity));
-  SE2_THREAD_CHECK_OOM(specificity);
-  IGRAPH_FINALLY(igraph_free, specificity);
-
-  igraph_vector_int_t *community_sizes =
+  igraph_vector_int_t* community_sizes =
     igraph_malloc(sizeof(*community_sizes));
   SE2_THREAD_CHECK_OOM(community_sizes);
   IGRAPH_FINALLY(igraph_free, community_sizes);
 
-  igraph_matrix_t *local_labels_heard =
+  igraph_matrix_t* local_labels_heard =
     igraph_malloc(sizeof(*local_labels_heard));
   SE2_THREAD_CHECK_OOM(local_labels_heard);
   IGRAPH_FINALLY(igraph_free, local_labels_heard);
 
-  igraph_vector_t *global_labels_heard =
+  igraph_vector_t* global_labels_heard =
     igraph_malloc(sizeof(*global_labels_heard));
   SE2_THREAD_CHECK_OOM(global_labels_heard);
   IGRAPH_FINALLY(igraph_free, global_labels_heard);
@@ -126,8 +119,6 @@ igraph_error_t se2_partition_init(se2_partition *partition,
   IGRAPH_FINALLY(igraph_vector_int_destroy, reference);
   SE2_THREAD_CHECK(igraph_vector_int_init(stage, n_nodes));
   IGRAPH_FINALLY(igraph_vector_int_destroy, stage);
-  SE2_THREAD_CHECK(igraph_vector_init(specificity, n_nodes));
-  IGRAPH_FINALLY(igraph_vector_destroy, specificity);
   SE2_THREAD_CHECK(igraph_vector_int_init(community_sizes, 0));
   IGRAPH_FINALLY(igraph_vector_int_destroy, community_sizes);
 
@@ -140,63 +131,56 @@ igraph_error_t se2_partition_init(se2_partition *partition,
   partition->n_nodes = n_nodes;
   partition->reference = reference;
   partition->stage = stage;
-  partition->label_quality = specificity;
   partition->community_sizes = community_sizes;
   partition->n_labels = n_labels;
   partition->max_label = igraph_vector_int_size(community_sizes) - 1;
   partition->local_labels_heard = local_labels_heard;
   partition->global_labels_heard = global_labels_heard;
 
-  SE2_THREAD_CHECK(igraph_matrix_init(local_labels_heard, n_nodes,
-                                      partition->max_label + 1));
+  SE2_THREAD_CHECK(
+    igraph_matrix_init(local_labels_heard, n_nodes, partition->max_label + 1));
   IGRAPH_FINALLY(igraph_matrix_destroy, local_labels_heard);
   SE2_THREAD_CHECK(
     igraph_vector_init(global_labels_heard, partition->max_label + 1));
   IGRAPH_FINALLY(igraph_vector_destroy, global_labels_heard);
 
   SE2_THREAD_CHECK(se2_count_local_labels(
-                     graph, initial_labels, partition->max_label, local_labels_heard));
+    graph, initial_labels, partition->max_label, local_labels_heard));
   SE2_THREAD_CHECK(se2_count_global_labels(
-                     graph, partition->max_label, local_labels_heard, global_labels_heard));
+    graph, partition->max_label, local_labels_heard, global_labels_heard));
 
-  IGRAPH_FINALLY_CLEAN(12);
+  IGRAPH_FINALLY_CLEAN(10);
 
   return IGRAPH_SUCCESS;
 }
 
-void se2_partition_destroy(se2_partition *partition)
+void se2_partition_destroy(se2_partition* partition)
 {
   igraph_vector_int_destroy(partition->reference);
   igraph_vector_int_destroy(partition->stage);
-  igraph_vector_destroy(partition->label_quality);
   igraph_vector_int_destroy(partition->community_sizes);
   igraph_matrix_destroy(partition->local_labels_heard);
   igraph_vector_destroy(partition->global_labels_heard);
 
   igraph_free(partition->reference);
   igraph_free(partition->stage);
-  igraph_free(partition->label_quality);
   igraph_free(partition->community_sizes);
   igraph_free(partition->local_labels_heard);
   igraph_free(partition->global_labels_heard);
 }
 
-void se2_iterator_shuffle(se2_iterator *iterator)
+void se2_iterator_shuffle(se2_iterator* iterator)
 {
   iterator->pos = 0;
   se2_randperm(iterator->ids, iterator->n_total, iterator->n_iter);
 }
 
-void se2_iterator_reset(se2_iterator *iterator)
-{
-  iterator->pos = 0;
-}
+void se2_iterator_reset(se2_iterator* iterator) { iterator->pos = 0; }
 
 // WARNING: Iterator does not take ownership of the id vector so it must still
 // be cleaned up by the caller.
-igraph_error_t se2_iterator_from_vector(se2_iterator *iterator,
-                                        igraph_vector_int_t *ids,
-                                        igraph_integer_t const n_iter)
+igraph_error_t se2_iterator_from_vector(se2_iterator* iterator,
+  igraph_vector_int_t* ids, igraph_integer_t const n_iter)
 {
   igraph_integer_t const n = igraph_vector_int_size(ids);
   iterator->ids = ids;
@@ -208,13 +192,12 @@ igraph_error_t se2_iterator_from_vector(se2_iterator *iterator,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_iterator_random_node_init(se2_iterator *iterator,
-    se2_partition const *partition,
-    igraph_real_t const proportion)
+igraph_error_t se2_iterator_random_node_init(se2_iterator* iterator,
+  se2_partition const* partition, igraph_real_t const proportion)
 {
   igraph_integer_t n_total = partition->n_nodes;
   igraph_integer_t n_iter = n_total;
-  igraph_vector_int_t *nodes = igraph_malloc(sizeof(*nodes));
+  igraph_vector_int_t* nodes = igraph_malloc(sizeof(*nodes));
   SE2_THREAD_CHECK_OOM(nodes);
   IGRAPH_FINALLY(igraph_free, nodes);
 
@@ -225,7 +208,7 @@ igraph_error_t se2_iterator_random_node_init(se2_iterator *iterator,
   }
 
   if (proportion) {
-    n_iter = n_total *proportion;
+    n_iter = n_total * proportion;
   }
 
   se2_iterator_from_vector(iterator, nodes, n_iter);
@@ -238,13 +221,12 @@ igraph_error_t se2_iterator_random_node_init(se2_iterator *iterator,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_iterator_random_label_init(se2_iterator *iterator,
-    se2_partition const *partition,
-    igraph_real_t const proportion)
+igraph_error_t se2_iterator_random_label_init(se2_iterator* iterator,
+  se2_partition const* partition, igraph_real_t const proportion)
 {
   igraph_integer_t n_total = partition->n_labels;
   igraph_integer_t n_iter = n_total;
-  igraph_vector_int_t *labels = igraph_malloc(sizeof(*labels));
+  igraph_vector_int_t* labels = igraph_malloc(sizeof(*labels));
   SE2_THREAD_CHECK_OOM(labels);
   IGRAPH_FINALLY(igraph_free, labels);
 
@@ -258,7 +240,7 @@ igraph_error_t se2_iterator_random_label_init(se2_iterator *iterator,
   }
 
   if (proportion) {
-    n_iter = n_total *proportion;
+    n_iter = n_total * proportion;
   }
 
   se2_iterator_from_vector(iterator, labels, n_iter);
@@ -271,33 +253,65 @@ igraph_error_t se2_iterator_random_label_init(se2_iterator *iterator,
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_iterator_k_worst_fit_nodes_init(se2_iterator *iterator,
-    se2_partition const *partition,
-    igraph_integer_t const k)
+/* Returns the top n_nodes - k fitting nodes in best_fit_nodes if passed in.
+   If proportion is set to a value other than 0, only iterator over a random
+   sample of k * proportion nodes. */
+igraph_error_t se2_iterator_k_worst_fit_nodes_init(se2_iterator* iterator,
+  se2_neighs const* graph, se2_partition const* partition,
+  igraph_integer_t const k, igraph_real_t proportion,
+  igraph_vector_int_t* best_fit_nodes)
 {
-  igraph_vector_int_t *ids = igraph_malloc(sizeof(*ids));
+  igraph_integer_t n_iter = k;
+  igraph_vector_t label_quality;
+  igraph_vector_int_t* ids = igraph_malloc(sizeof(*ids));
   SE2_THREAD_CHECK_OOM(ids);
   IGRAPH_FINALLY(igraph_free, ids);
 
   SE2_THREAD_CHECK(igraph_vector_int_init(ids, partition->n_nodes));
   IGRAPH_FINALLY(igraph_vector_int_destroy, ids);
 
+  SE2_THREAD_CHECK(igraph_vector_init(&label_quality, partition->n_nodes));
+  IGRAPH_FINALLY(igraph_vector_destroy, &label_quality);
+
+  for (igraph_integer_t i = 0; i < partition->n_nodes; i++) {
+    VECTOR(label_quality)
+    [i] = se2_partition_score_label(graph, partition, i, LABEL(*partition)[i]);
+  }
+
   SE2_THREAD_CHECK(
-    igraph_vector_qsort_ind(partition->label_quality, ids, IGRAPH_ASCENDING));
+    igraph_vector_qsort_ind(&label_quality, ids, IGRAPH_ASCENDING));
+  igraph_vector_destroy(&label_quality);
+  IGRAPH_FINALLY_CLEAN(1);
+
+  if (best_fit_nodes) {
+    SE2_THREAD_CHECK(
+      igraph_vector_int_init(best_fit_nodes, partition->n_nodes - k));
+    IGRAPH_FINALLY(igraph_vector_int_destroy, best_fit_nodes);
+    for (igraph_integer_t i = k; i < partition->n_nodes; i++) {
+      VECTOR(*best_fit_nodes)[i - k] = VECTOR(*ids)[i];
+    }
+  }
   SE2_THREAD_CHECK(igraph_vector_int_resize(ids, k));
 
-  SE2_THREAD_CHECK(se2_iterator_from_vector(iterator, ids, k));
+  if (proportion) {
+    n_iter *= proportion;
+  }
+
+  SE2_THREAD_CHECK(se2_iterator_from_vector(iterator, ids, n_iter));
   IGRAPH_FINALLY(se2_iterator_destroy, iterator);
 
   iterator->owns_ids = true;
   se2_iterator_shuffle(iterator);
 
   IGRAPH_FINALLY_CLEAN(3);
+  if (best_fit_nodes) {
+    IGRAPH_FINALLY_CLEAN(1);
+  }
 
   return IGRAPH_SUCCESS;
 }
 
-void se2_iterator_destroy(se2_iterator *iterator)
+void se2_iterator_destroy(se2_iterator* iterator)
 {
   if (iterator->owns_ids) {
     igraph_vector_int_destroy(iterator->ids);
@@ -305,7 +319,7 @@ void se2_iterator_destroy(se2_iterator *iterator)
   }
 }
 
-igraph_integer_t se2_iterator_next(se2_iterator *iterator)
+igraph_integer_t se2_iterator_next(se2_iterator* iterator)
 {
   igraph_integer_t n = 0;
   if (iterator->pos == iterator->n_iter) {
@@ -319,32 +333,29 @@ igraph_integer_t se2_iterator_next(se2_iterator *iterator)
   return n;
 }
 
-igraph_integer_t se2_partition_n_nodes(se2_partition const *partition)
+igraph_integer_t se2_partition_n_nodes(se2_partition const* partition)
 {
   return partition->n_nodes;
 }
 
-igraph_integer_t se2_partition_n_labels(se2_partition const *partition)
+igraph_integer_t se2_partition_n_labels(se2_partition const* partition)
 {
   return partition->n_labels;
 }
 
-igraph_integer_t se2_partition_max_label(se2_partition const *partition)
+igraph_integer_t se2_partition_max_label(se2_partition const* partition)
 {
   return partition->max_label;
 }
 
-void se2_partition_add_to_stage(se2_partition *partition,
-                                igraph_integer_t const node_id,
-                                igraph_integer_t const label,
-                                igraph_real_t specificity)
+void se2_partition_add_to_stage(se2_partition* partition,
+  igraph_integer_t const node_id, igraph_integer_t const label)
 {
   VECTOR(*partition->stage)[node_id] = label;
-  VECTOR(*partition->label_quality)[node_id] = specificity;
 }
 
 // Return an unused label.
-igraph_integer_t se2_partition_new_label(se2_partition *partition)
+igraph_integer_t se2_partition_new_label(se2_partition* partition)
 {
   igraph_integer_t pool_size =
     igraph_vector_int_size(partition->community_sizes);
@@ -356,8 +367,8 @@ igraph_integer_t se2_partition_new_label(se2_partition *partition)
 
   if (next_label == igraph_vector_int_capacity(partition->community_sizes)) {
     SE2_THREAD_CHECK_RETURN(
-      igraph_vector_int_reserve(partition->community_sizes,
-                                MAX(2 * pool_size, partition->n_nodes)),
+      igraph_vector_int_reserve(
+        partition->community_sizes, MAX(2 * pool_size, partition->n_nodes)),
       -1);
   }
 
@@ -378,8 +389,8 @@ igraph_integer_t se2_partition_new_label(se2_partition *partition)
   return next_label;
 }
 
-static inline void se2_partition_free_label(se2_partition *partition,
-    igraph_integer_t const label)
+static inline void se2_partition_free_label(
+  se2_partition* partition, igraph_integer_t const label)
 {
   VECTOR(*partition->community_sizes)[label] = 0;
   if (label == partition->max_label) {
@@ -392,13 +403,13 @@ static inline void se2_partition_free_label(se2_partition *partition,
   partition->n_labels--;
 }
 
-igraph_integer_t se2_partition_community_size(se2_partition const *partition,
-    igraph_integer_t const label)
+igraph_integer_t se2_partition_community_size(
+  se2_partition const* partition, igraph_integer_t const label)
 {
   return VECTOR(*partition->community_sizes)[label];
 }
 
-igraph_real_t se2_vector_median(igraph_vector_t const *vec)
+igraph_real_t se2_vector_median(igraph_vector_t const* vec)
 {
   igraph_vector_int_t ids;
   igraph_integer_t len = igraph_vector_size(vec) - 1;
@@ -407,8 +418,8 @@ igraph_real_t se2_vector_median(igraph_vector_t const *vec)
 
   SE2_THREAD_CHECK_RETURN(igraph_vector_int_init(&ids, len), 0);
   IGRAPH_FINALLY(igraph_vector_int_destroy, &ids);
-  SE2_THREAD_CHECK_RETURN(igraph_vector_qsort_ind(vec, &ids, IGRAPH_ASCENDING),
-                          0);
+  SE2_THREAD_CHECK_RETURN(
+    igraph_vector_qsort_ind(vec, &ids, IGRAPH_ASCENDING), 0);
   res = VECTOR(*vec)[VECTOR(ids)[k]];
 
   if (len % 2) {
@@ -421,7 +432,8 @@ igraph_real_t se2_vector_median(igraph_vector_t const *vec)
 
   return res;
 }
-igraph_real_t se2_vector_int_median(igraph_vector_int_t const *vec)
+
+igraph_real_t se2_vector_int_median(igraph_vector_int_t const* vec)
 {
   igraph_vector_int_t ids;
   igraph_integer_t len = igraph_vector_int_size(vec) - 1;
@@ -445,8 +457,8 @@ igraph_real_t se2_vector_int_median(igraph_vector_int_t const *vec)
   return res;
 }
 
-igraph_integer_t se2_partition_median_community_size(se2_partition const
-    *partition)
+igraph_real_t se2_partition_median_community_size(
+  se2_partition const* partition)
 {
   if (partition->n_labels == 1) {
     return partition->n_nodes;
@@ -454,7 +466,7 @@ igraph_integer_t se2_partition_median_community_size(se2_partition const
 
   igraph_vector_int_t community_sizes;
   se2_iterator label_iter;
-  igraph_integer_t res = 0;
+  igraph_real_t res = 0;
 
   SE2_THREAD_CHECK_RETURN(
     se2_iterator_random_label_init(&label_iter, partition, 0), 0);
@@ -470,8 +482,8 @@ igraph_integer_t se2_partition_median_community_size(se2_partition const
     [label_i] = se2_partition_community_size(partition, label_id);
     label_i++;
   }
-  SE2_THREAD_CHECK_RETURN(igraph_vector_int_resize(&community_sizes, label_i),
-                          0);
+  SE2_THREAD_CHECK_RETURN(
+    igraph_vector_int_resize(&community_sizes, label_i), 0);
 
   res = se2_vector_int_median(&community_sizes);
 
@@ -482,8 +494,8 @@ igraph_integer_t se2_partition_median_community_size(se2_partition const
   return res;
 }
 
-void se2_partition_merge_labels(se2_partition *partition, igraph_integer_t c1,
-                                igraph_integer_t c2)
+void se2_partition_merge_labels(
+  se2_partition* partition, igraph_integer_t c1, igraph_integer_t c2)
 {
   // Ensure smaller community engulfed by larger community. Not necessary.
   if (se2_partition_community_size(partition, c2) >
@@ -503,8 +515,8 @@ void se2_partition_merge_labels(se2_partition *partition, igraph_integer_t c1,
 }
 
 // Move nodes in mask to new label.
-igraph_error_t se2_partition_relabel_mask(se2_partition *partition,
-    igraph_vector_bool_t const *mask)
+igraph_error_t se2_partition_relabel_mask(
+  se2_partition* partition, igraph_vector_bool_t const* mask)
 {
   igraph_integer_t label = se2_partition_new_label(partition);
   SE2_THREAD_STATUS();
@@ -518,21 +530,21 @@ igraph_error_t se2_partition_relabel_mask(se2_partition *partition,
 }
 
 static igraph_error_t se2_partition_recount_community_sizes(
-  se2_partition *partition)
+  se2_partition* partition)
 {
   partition->n_labels =
     se2_count_labels(partition->stage, partition->community_sizes);
   SE2_THREAD_STATUS();
-  partition->max_label = igraph_vector_int_size(partition->community_sizes) - 1;
+  partition->max_label =
+    igraph_vector_int_size(partition->community_sizes) - 1;
 
   return IGRAPH_SUCCESS;
 }
 
-static igraph_error_t se2_resize_local_labels(se2_partition *partition,
-    igraph_integer_t const n_nodes,
-    igraph_integer_t n_labels)
+static igraph_error_t se2_resize_local_labels(se2_partition* partition,
+  igraph_integer_t const n_nodes, igraph_integer_t n_labels)
 {
-  igraph_matrix_t *new_local_labels = igraph_malloc(sizeof(*new_local_labels));
+  igraph_matrix_t* new_local_labels = igraph_malloc(sizeof(*new_local_labels));
   SE2_THREAD_CHECK_OOM(new_local_labels);
   IGRAPH_FINALLY(igraph_free, new_local_labels);
 
@@ -561,8 +573,8 @@ static igraph_error_t se2_resize_local_labels(se2_partition *partition,
 
 /* For each node that switched labels, move their edge weights from the old
    label to the new label. */
-static igraph_error_t se2_move_labels_heard(se2_partition *partition,
-    se2_neighs const *graph)
+static igraph_error_t se2_move_labels_heard(
+  se2_partition* partition, se2_neighs const* graph)
 {
   igraph_integer_t old_max_label =
     igraph_vector_size(partition->global_labels_heard) - 1;
@@ -602,17 +614,17 @@ static igraph_error_t se2_move_labels_heard(se2_partition *partition,
 
     for (igraph_integer_t j = 0; j < N_NEIGHBORS(*graph, node_id); j++) {
       MATRIX(*partition->local_labels_heard, NEIGHBOR(*graph, node_id, j),
-             old_label) -= WEIGHT(*graph, node_id, j);
+        old_label) -= WEIGHT(*graph, node_id, j);
       MATRIX(*partition->local_labels_heard, NEIGHBOR(*graph, node_id, j),
-             new_label) += WEIGHT(*graph, node_id, j);
+        new_label) += WEIGHT(*graph, node_id, j);
     }
   }
 
   return IGRAPH_SUCCESS;
 }
 
-igraph_error_t se2_partition_commit_changes(se2_partition *partition,
-    se2_neighs const *graph)
+igraph_error_t se2_partition_commit_changes(
+  se2_partition* partition, se2_neighs const* graph)
 {
   SE2_THREAD_CHECK(se2_partition_recount_community_sizes(partition));
   SE2_THREAD_CHECK(se2_move_labels_heard(partition, graph));
@@ -622,7 +634,7 @@ igraph_error_t se2_partition_commit_changes(se2_partition *partition,
   return IGRAPH_SUCCESS;
 }
 
-static igraph_error_t se2_reindex_membership(igraph_vector_int_t *membership)
+static igraph_error_t se2_reindex_membership(igraph_vector_int_t* membership)
 {
   igraph_vector_int_t indices;
   igraph_integer_t n_nodes = igraph_vector_int_size(membership);
@@ -655,11 +667,10 @@ partition store.
 NOTE: This saves only the membership ids for each node so it goes from a
 se2_partition to an igraph vector despite both arguments being
 "partitions". */
-igraph_error_t se2_partition_store(se2_partition const *working_partition,
-                                   igraph_vector_int_list_t *partition_store,
-                                   igraph_integer_t const idx)
+igraph_error_t se2_partition_store(se2_partition const* working_partition,
+  igraph_vector_int_list_t* partition_store, igraph_integer_t const idx)
 {
-  igraph_vector_int_t *partition_state =
+  igraph_vector_int_t* partition_state =
     igraph_vector_int_list_get_ptr(partition_store, idx);
 
   SE2_THREAD_CHECK(
@@ -669,3 +680,16 @@ igraph_error_t se2_partition_store(se2_partition const *working_partition,
 
   return IGRAPH_SUCCESS;
 }
+
+igraph_real_t se2_partition_score_label(se2_neighs const* graph,
+  se2_partition const* partition, igraph_integer_t const node_id,
+  igraph_integer_t const label_id)
+{
+  igraph_real_t actual =
+    MATRIX(*partition->local_labels_heard, node_id, label_id);
+  igraph_real_t expected = VECTOR(*partition->global_labels_heard)[label_id];
+  igraph_real_t norm_factor =
+    VECTOR(*graph->kin)[node_id] / graph->total_weight;
+
+  return actual - (norm_factor * expected);
+}
